@@ -36,10 +36,8 @@ print_bpf_filter_code(const uint16_t code, bool extended)
 	const struct xlat *mode = extended ? ebpf_mode : bpf_mode;
 	uint16_t i = code & ~BPF_CLASS(code);
 
-	if (extended)
-		printxval_index(ebpf_class, BPF_CLASS(code), "BPF_???");
-	else
-		printxval_index(bpf_class, BPF_CLASS(code), "BPF_???");
+	printxval(extended ? ebpf_class : bpf_class, BPF_CLASS(code),
+		  "BPF_???");
 	switch (BPF_CLASS(code)) {
 	case BPF_ST:
 	case BPF_STX:
