@@ -2,7 +2,7 @@
  * Decoder of socket filter programs.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -14,7 +14,9 @@
 
 #include <linux/filter.h>
 #include "xlat/skf_ad.h"
-#include "xlat/skf_off.h"
+#define XLAT_MACROS_ONLY
+# include "xlat/skf_off.h"
+#undef XLAT_MACROS_ONLY
 
 static bool
 print_sock_filter_k(const struct bpf_filter_block *const fp)
