@@ -1,16 +1,17 @@
 /*
  * Copyright (c) 2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #ifndef STRACE_GET_PERSONALITY_H
-#define STRACE_GET_PERSONALITY_H
+# define STRACE_GET_PERSONALITY_H
 
-#include "ptrace.h"
+# include "ptrace.h"
 
 extern int
-get_personality_from_syscall_info(const struct ptrace_syscall_info *);
+get_personality_from_syscall_info(const struct_ptrace_syscall_info *);
 
 #endif /* !STRACE_GET_PERSONALITY_H */
