@@ -336,6 +336,8 @@ ioctl_decode(struct tcb *tcp)
 	case 0x94:
 		return btrfs_ioctl(tcp, code, arg);
 #endif
+	case 0xa4:
+		return tee_ioctl(tcp, code, arg);
 #ifdef HAVE_LINUX_USERFAULTFD_H
 	case 0xaa:
 		return uffdio_ioctl(tcp, code, arg);
