@@ -5,19 +5,16 @@
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
  * Copyright (c) 2003-2006 Roland McGrath <roland@redhat.com>
  * Copyright (c) 2006-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "defs.h"
+#include "ipc_defs.h"
 
-#ifdef HAVE_SYS_SHM_H
-# include <sys/shm.h>
-#elif defined HAVE_LINUX_SHM_H
-# include <linux/shm.h>
-#endif
+#include SHM_H_PROVIDER
 
 #ifndef SHM_HUGE_SHIFT
 # define SHM_HUGE_SHIFT 26
