@@ -1,9 +1,16 @@
+/*
+ * Copyright (c) 2015-2018 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
 static void
 arch_sigreturn(struct tcb *tcp)
 {
 	unsigned long addr;
 
-	if (upeek(tcp, REG_FP, &addr) < 0)
+	if (!get_stack_pointer(tcp, &addr))
 		return;
 	addr += offsetof(struct sigcontext, sc_mask);
 
