@@ -1,4 +1,11 @@
-	"SIG_0",	/* 0 */
+/*
+ * Copyright (c) 1999-2018 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+	"0",		/* 0 */
 	"SIGHUP",	/* 1 */
 	"SIGINT",	/* 2 */
 	"SIGQUIT",	/* 3 */
