@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread"			},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite"		},
@@ -244,7 +244,7 @@
 [235] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [236] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[238] = { 2,	TS,		SEN(kill),			"tkill"			},
+[238] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -277,7 +277,7 @@
 [268] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [269] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [270] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[271] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[271] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [272] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [273] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [274] = { 5,	0,		SEN(vserver),			"vserver"		},
@@ -316,7 +316,7 @@
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[310] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[310] = { 1,	0,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(sram_alloc),		"sram_alloc"		},
 [312] = { 1,	0,		SEN(printargs),			"sram_free"		},
 [313] = { 3,	0,		SEN(printargs),			"dma_memcpy"		},
