@@ -1,20 +1,28 @@
+/*
+ * Copyright (c) 2015-2018 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
 static void
 arch_sigreturn(struct tcb *tcp)
 {
-	unsigned long addr;
+	unsigned long addr, sp;
 
 	/* Fetch pointer to struct sigcontext.  */
-	if (umove(tcp, *m68k_usp_ptr + 2 * sizeof(int), &addr) < 0)
+	if (!get_stack_pointer(tcp, &sp) ||
+	    umove_or_printaddr(tcp, sp + 2 * sizeof(int), &addr))
 		return;
 
 	unsigned long mask[NSIG_BYTES / sizeof(long)];
 	/* Fetch first word of signal mask.  */
-	if (umove(tcp, addr, &mask[0]) < 0)
+	if (umove_or_printaddr(tcp, addr, &mask[0]))
 		return;
 
 	/* Fetch remaining words of signal mask, located immediately before.  */
 	addr -= sizeof(mask) - sizeof(long);
-	if (umoven(tcp, addr, sizeof(mask) - sizeof(long), &mask[1]) < 0)
+	if (umoven_or_printaddr(tcp, addr, sizeof(mask) - sizeof(long), &mask[1]))
 		return;
 
 	tprintsigmask_addr("{mask=", mask);
