@@ -42,7 +42,7 @@
 [  34] = { 0,	0,	SEN(printargs),		"svr4_nice"	},
 [  35] = { 0,	TF|TSF|TSFA,SEN(printargs),		"svr4_statfs"	},
 [  36] = { 0,	0,	SEN(printargs),		"svr4_sync"	},
-[  37] = { 0,	0,	SEN(printargs),		"svr4_kill"	},
+[  37] = { 0,	TP,	SEN(printargs),		"svr4_kill"	},
 [  38] = { 0,	TD|TFSF|TSFA,SEN(printargs),		"svr4_fstatfs"	},
 [  39] = { 0,	0,	SEN(printargs),		"svr4_setpgrp"	},
 [  40] = { 0,	0,	SEN(printargs),		"svr4_cxenix"	},
@@ -193,7 +193,7 @@
 [1034] = { 0,	0,	SEN(printargs),		"sysv_nice"	},
 [1035] = { 0,	TF|TSF|TSFA,SEN(printargs),		"sysv_statfs"	},
 [1036] = { 0,	0,	SEN(printargs),		"sysv_sync"	},
-[1037] = { 0,	0,	SEN(printargs),		"sysv_kill"	},
+[1037] = { 0,	TP,	SEN(printargs),		"sysv_kill"	},
 [1038] = { 0,	TD|TFSF|TSFA,SEN(printargs),		"sysv_fstatfs"	},
 [1039] = { 0,	0,	SEN(printargs),		"sysv_setpgrp"	},
 [1040] = { 0,	0,	SEN(printargs),		"sysv_syssgi"	},
@@ -378,7 +378,7 @@
 [2034] = { 0,	0,	SEN(printargs),		"bsd43_nice"	},
 [2035] = { 0,	0,	SEN(printargs),		"bsd43_ftime"	},
 [2036] = { 0,	0,	SEN(printargs),		"bsd43_sync"	},
-[2037] = { 0,	0,	SEN(printargs),		"bsd43_kill"	},
+[2037] = { 0,	TP,	SEN(printargs),		"bsd43_kill"	},
 [2038] = { 0,	TF|TST|TSTA,SEN(printargs),		"bsd43_stat"	},
 [2039] = { 0,	0,	SEN(printargs),		"bsd43_oldsetpgrp"	},
 [2040] = { 0,	TF|TLST|TSTA,SEN(printargs),		"bsd43_lstat"	},
@@ -487,7 +487,7 @@
 [2143] = { 0,	0,	SEN(printargs),		"bsd43_sethostid"	},
 [2144] = { 0,	0,	SEN(printargs),		"bsd43_getrlimit"	},
 [2145] = { 0,	0,	SEN(printargs),		"bsd43_setrlimit"	},
-[2146] = { 0,	0,	SEN(printargs),		"bsd43_killpg"	},
+[2146] = { 0,	TP,	SEN(printargs),		"bsd43_killpg"	},
 [2147] = { 0,	0,	SEN(printargs),		"bsd43_shmsys"	},
 [2148] = { 0,	0,	SEN(printargs),		"bsd43_quota"	},
 [2149] = { 0,	0,	SEN(printargs),		"bsd43_qquota"	},
@@ -571,7 +571,7 @@
 [3034] = { 0,	0,	SEN(printargs),		"posix_nice"	},
 [3035] = { 0,	TF|TSF|TSFA,SEN(printargs),		"posix_statfs"	},
 [3036] = { 0,	0,	SEN(printargs),		"posix_sync"	},
-[3037] = { 0,	0,	SEN(printargs),		"posix_kill"	},
+[3037] = { 0,	TP,	SEN(printargs),		"posix_kill"	},
 [3038] = { 0,	TD|TFSF|TSFA,SEN(printargs),		"posix_fstatfs"	},
 [3039] = { 0,	0,	SEN(printargs),		"posix_getpgrp"	},
 [3040] = { 0,	0,	SEN(printargs),		"posix_syssgi"	},
