@@ -1,6 +1,13 @@
+/*
+ * Copyright (c) 2015-2018 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
 /* Return -1 on error or 1 on success (never 0!). */
 static int
-get_syscall_args(struct tcb *tcp)
+arch_get_syscall_args(struct tcb *tcp)
 {
 	tcp->u_arg[0] = or1k_regs.gpr[3 + 0];
 	tcp->u_arg[1] = or1k_regs.gpr[3 + 1];
