@@ -1,3 +1,10 @@
+/*
+ * Copyright (c) 2015-2018 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
 #include "negated_errno.h"
 
 #ifndef ARCH_REGSET
@@ -5,7 +12,7 @@
 #endif
 
 static void
-get_error(struct tcb *tcp, const bool check_errno)
+arch_get_error(struct tcb *tcp, const bool check_errno)
 {
 	if (check_errno && is_negated_errno(ARCH_REGSET.gprs[2])) {
 		tcp->u_rval = -1;
