@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,13 +8,13 @@
 static int
 arch_set_error(struct tcb *tcp)
 {
-	sh_r0 = -tcp->u_error;
-	return upoke(tcp, 4 * REG_REG0, sh_r0);
+	sh_regs.regs[0] = -tcp->u_error;
+	return set_regs(tcp->pid);
 }
 
 static int
 arch_set_success(struct tcb *tcp)
 {
-	sh_r0 = tcp->u_rval;
-	return upoke(tcp, 4 * REG_REG0, sh_r0);
+	sh_regs.regs[0] = tcp->u_rval;
+	return set_regs(tcp->pid);
 }
