@@ -9,8 +9,6 @@ static int
 sparc_set_o0_psr(struct tcb *tcp, const unsigned long o0,
 		 const unsigned long psr_set, const unsigned long psr_clear)
 {
-	if (ptrace_syscall_info_is_valid() && get_regs(tcp) < 0)
-		return -1;
 	sparc_regs.u_regs[U_REG_O0] = o0;
 	sparc_regs.psr |= psr_set;
 	sparc_regs.psr &= ~psr_clear;
