@@ -13,3 +13,6 @@
 #define PERSONALITY0_AUDIT_ARCH { AUDIT_ARCH_X86_64, 0 }
 #define PERSONALITY1_AUDIT_ARCH { AUDIT_ARCH_I386,   0 }
 #define PERSONALITY2_AUDIT_ARCH { AUDIT_ARCH_X86_64, __X32_SYSCALL_BIT }
+#ifndef __X32_SYSCALL_BIT
+# define __X32_SYSCALL_BIT 0x40000000UL
+#endif
