@@ -1,5 +1,9 @@
-extern uint32_t *const i386_esp_ptr;
-extern uint64_t *const x86_64_rsp_ptr;
+/*
+ * Copyright (c) 2015-2018 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 /* <asm/ptrace.h> does not provide these definitions.  */
 #define R15		0
