@@ -1,14 +1,13 @@
 /*
  * Copyright (c) 2012 The Chromium OS Authors.
- * Copyright (c) 2012-2018 The strace developers.
+ * Copyright (c) 2012-2020 The strace developers.
  * Written by Mike Frysinger <vapier@gentoo.org>.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "defs.h"
-#include <linux/ioctl.h>
-#include <linux/loop.h>
+#include "types/loop.h"
 
 typedef struct loop_info struct_loop_info;
 
@@ -34,30 +33,28 @@ decode_loop_info(struct tcb *const tcp, const kernel_ulong_t addr)
 	if (umove_or_printaddr(tcp, addr, &info))
 		return;
 
-	tprintf("{lo_number=%d", info.lo_number);
+	PRINT_FIELD_D("{", info, lo_number);
 
 	if (!abbrev(tcp)) {
 		PRINT_FIELD_DEV(", ", info, lo_device);
-		tprintf(", lo_inode=%" PRI_klu, (kernel_ulong_t) info.lo_inode);
+		PRINT_FIELD_U(", ", info, lo_inode);
 		PRINT_FIELD_DEV(", ", info, lo_rdevice);
 	}
 
-	tprintf(", lo_offset=%#x", info.lo_offset);
+	PRINT_FIELD_X(", ", info, lo_offset);
 
 	if (!abbrev(tcp) || info.lo_encrypt_type != LO_CRYPT_NONE) {
-		tprints(", lo_encrypt_type=");
-		printxval(loop_crypt_type_options, info.lo_encrypt_type,
-			"LO_CRYPT_???");
+		PRINT_FIELD_XVAL(", ", info, lo_encrypt_type,
+				 loop_crypt_type_options, "LO_CRYPT_???");
 		/*
-		 * It is converted to unsigned before use in kernel, see
-		 * loop_info64_from_old in drivers/block/loop.c
+		 * It is converted to unsigned before use in the kernel,
+		 * see loop_info64_from_old in drivers/block/loop.c
 		 */
-		tprintf(", lo_encrypt_key_size=%" PRIu32,
-			(uint32_t) info.lo_encrypt_key_size);
+		PRINT_FIELD_U(", ", info, lo_encrypt_key_size);
 	}
 
-	tprints(", lo_flags=");
-	printflags(loop_flags_options, info.lo_flags, "LO_FLAGS_???");
+	PRINT_FIELD_FLAGS(", ", info, lo_flags,
+			  loop_flags_options, "LO_FLAGS_???");
 
 	PRINT_FIELD_CSTRING(", ", info, lo_name);
 
@@ -68,15 +65,56 @@ decode_loop_info(struct tcb *const tcp, const kernel_ulong_t addr)
 					  lo_encrypt_key_size, 0);
 	}
 
+	if (!abbrev(tcp)) {
+		PRINT_FIELD_X_ARRAY(", ", info, lo_init);
+		PRINT_FIELD_X_ARRAY(", ", info, reserved);
+	} else {
+		tprints(", ...");
+	}
+
+	tprints("}");
+}
+
+static void
+print_loop_info64(struct tcb *const tcp, const struct loop_info64 *const info64)
+{
+	if (!abbrev(tcp)) {
+		PRINT_FIELD_DEV("{", *info64, lo_device);
+		PRINT_FIELD_U(", ", *info64, lo_inode);
+		PRINT_FIELD_DEV(", ", *info64, lo_rdevice);
+		PRINT_FIELD_X(", ", *info64, lo_offset);
+		PRINT_FIELD_U(", ", *info64, lo_sizelimit);
+		PRINT_FIELD_U(", ", *info64, lo_number);
+	} else {
+		PRINT_FIELD_X("{", *info64, lo_offset);
+		PRINT_FIELD_U(", ", *info64, lo_number);
+	}
+
+	if (!abbrev(tcp) || info64->lo_encrypt_type != LO_CRYPT_NONE) {
+		PRINT_FIELD_XVAL(", ", *info64, lo_encrypt_type,
+				 loop_crypt_type_options, "LO_CRYPT_???");
+		PRINT_FIELD_U(", ", *info64, lo_encrypt_key_size);
+	}
+
+	PRINT_FIELD_FLAGS(", ", *info64, lo_flags,
+			  loop_flags_options, "LO_FLAGS_???");
+
+	PRINT_FIELD_CSTRING(", ", *info64, lo_file_name);
+
+	if (!abbrev(tcp) || info64->lo_encrypt_type != LO_CRYPT_NONE) {
+		PRINT_FIELD_CSTRING(", ", *info64, lo_crypt_name);
+		const unsigned int lo_encrypt_key_size =
+			MIN((unsigned) info64->lo_encrypt_key_size, LO_KEY_SIZE);
+		PRINT_FIELD_STRING(", ", *info64, lo_encrypt_key,
+					  lo_encrypt_key_size, 0);
+	}
+
 	if (!abbrev(tcp))
-		tprintf(", lo_init=[%#" PRI_klx ", %#" PRI_klx "]"
-			", reserved=[%#hhx, %#hhx, %#hhx, %#hhx]}",
-			(kernel_ulong_t) info.lo_init[0],
-			(kernel_ulong_t) info.lo_init[1],
-			info.reserved[0], info.reserved[1],
-			info.reserved[2], info.reserved[3]);
+		PRINT_FIELD_X_ARRAY(", ", *info64, lo_init);
 	else
-		tprints(", ...}");
+		tprints(", ...");
+
+	tprints("}");
 }
 
 static void
@@ -85,51 +123,30 @@ decode_loop_info64(struct tcb *const tcp, const kernel_ulong_t addr)
 	struct loop_info64 info64;
 
 	tprints(", ");
-	if (umove_or_printaddr(tcp, addr, &info64))
+	if (!umove_or_printaddr(tcp, addr, &info64))
+		print_loop_info64(tcp, &info64);
+}
+
+static void
+decode_loop_config(struct tcb *const tcp, const kernel_ulong_t addr)
+{
+	struct_loop_config config;
+
+	tprints(", ");
+	if (umove_or_printaddr(tcp, addr, &config))
 		return;
 
-	if (!abbrev(tcp)) {
-		PRINT_FIELD_DEV("{", info64, lo_device);
-		tprintf(", lo_inode=%" PRIu64, (uint64_t) info64.lo_inode);
-		PRINT_FIELD_DEV(", ", info64, lo_rdevice);
-		tprintf(", lo_offset=%#" PRIx64 ", lo_sizelimit=%" PRIu64
-			", lo_number=%" PRIu32,
-			(uint64_t) info64.lo_offset,
-			(uint64_t) info64.lo_sizelimit,
-			(uint32_t) info64.lo_number);
-	} else {
-		tprintf("{lo_offset=%#" PRIx64 ", lo_number=%" PRIu32,
-			(uint64_t) info64.lo_offset,
-			(uint32_t) info64.lo_number);
-	}
+	PRINT_FIELD_FD("{", config, fd, tcp);
 
-	if (!abbrev(tcp) || info64.lo_encrypt_type != LO_CRYPT_NONE) {
-		tprints(", lo_encrypt_type=");
-		printxval(loop_crypt_type_options, info64.lo_encrypt_type,
-			"LO_CRYPT_???");
-		tprintf(", lo_encrypt_key_size=%" PRIu32,
-			info64.lo_encrypt_key_size);
-	}
+	PRINT_FIELD_U(", ", config, block_size);
 
-	tprints(", lo_flags=");
-	printflags(loop_flags_options, info64.lo_flags, "LO_FLAGS_???");
+	tprints(", info=");
+	print_loop_info64(tcp, &config.info);
 
-	PRINT_FIELD_CSTRING(", ", info64, lo_file_name);
+	if (!IS_ARRAY_ZERO(config.__reserved))
+		PRINT_FIELD_X_ARRAY(", ", config, __reserved);
 
-	if (!abbrev(tcp) || info64.lo_encrypt_type != LO_CRYPT_NONE) {
-		PRINT_FIELD_CSTRING(", ", info64, lo_crypt_name);
-		const unsigned int lo_encrypt_key_size =
-			MIN((unsigned) info64.lo_encrypt_key_size, LO_KEY_SIZE);
-		PRINT_FIELD_STRING(", ", info64, lo_encrypt_key,
-					  lo_encrypt_key_size, 0);
-	}
-
-	if (!abbrev(tcp))
-		tprintf(", lo_init=[%#" PRIx64 ", %#" PRIx64 "]}",
-			(uint64_t) info64.lo_init[0],
-			(uint64_t) info64.lo_init[1]);
-	else
-		tprints(", ...}");
+	tprints("}");
 }
 
 MPERS_PRINTER_DECL(int, loop_ioctl,
@@ -153,6 +170,10 @@ MPERS_PRINTER_DECL(int, loop_ioctl,
 		decode_loop_info64(tcp, arg);
 		break;
 
+	case LOOP_CONFIGURE:
+		decode_loop_config(tcp, arg);
+		break;
+
 	case LOOP_CLR_FD:
 	case LOOP_SET_CAPACITY:
 	/* newer loop-control stuff */
