@@ -3,7 +3,7 @@
  * Copyright (c) 2012-2013 Denys Vlasenko <vda.linux@googlemail.com>
  * Copyright (c) 2014 Masatake YAMATO <yamato@redhat.com>
  * Copyright (c) 2010-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -71,7 +71,7 @@ free_mmsgvec_data(void *ptr)
 struct mmsgvec_data {
 	char *timeout;
 	unsigned int count;
-	int namelen[IOV_MAX];
+	int namelen[0];
 };
 
 static void
