@@ -87,7 +87,12 @@ getfdpath_pid(pid_t pid, int fd, char *buf, unsigned bufsize)
 	if (fd < 0)
 		return -1;
 
-	xsprintf(linkpath, "/proc/%u/fd/%u", pid, fd);
+	int proc_pid = 0;
+	translate_pid(NULL, pid, PT_TID, &proc_pid);
+	if (!proc_pid)
+		return -1;
+
+	xsprintf(linkpath, "/proc/%u/fd/%u", proc_pid, fd);
 	n = readlink(linkpath, buf, bufsize - 1);
 	/*
 	 * NB: if buf is too small, readlink doesn't fail,
@@ -193,6 +198,7 @@ pathtrace_match_set(struct tcb *tcp, struct path_set *set)
 	 */
 
 	switch (s->sen) {
+	case SEN_close_range:
 	case SEN_dup2:
 	case SEN_dup3:
 	case SEN_kexec_file_load:
