@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -30,7 +30,7 @@ MPERS_PRINTER_DECL(void, print_group_req, struct tcb *const tcp,
 		printaddr(addr);
 	} else if (!umove_or_printaddr(tcp, addr, &greq)) {
 		PRINT_FIELD_IFINDEX("{", greq, gr_interface);
-		PRINT_FIELD_SOCKADDR(", ", greq, gr_group);
+		PRINT_FIELD_SOCKADDR(", ", greq, gr_group, tcp);
 		tprints("}");
 	}
 }
