@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -17,7 +17,7 @@
 DIAG_PUSH_IGNORE_OVERRIDE_INIT
 
 static uint8_t hwaddr_sizes[] = {
-	[0 ... ARPHRD_IEEE802_TR] = 255,
+	[0 ... ARPHRD_VSOCKMON] = 255,
 
 	[ARPHRD_NETROM]     =  7 /* AX25_ADDR_LEN */,
 	[ARPHRD_ETHER]      =  6 /* ETH_ALEN */,
@@ -114,10 +114,12 @@ void
 print_mac_addr(const char *prefix, const uint8_t addr[], size_t size)
 {
 	tprints(prefix);
-	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV)
+	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV
+	    || size > MAX_ADDR_LEN)
 		print_quoted_string((const char *) addr, size,
 				    QUOTE_FORCE_HEX);
-	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW)
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW
+	    || size > MAX_ADDR_LEN)
 		return;
 	(xlat_verbose(xlat_verbosity) == XLAT_STYLE_VERBOSE
 		? tprints_comment : tprints)(sprint_mac_addr(addr, size));
@@ -137,10 +139,12 @@ print_hwaddr(const char *prefix, const uint8_t addr[], size_t size,
 	     uint32_t devtype)
 {
 	tprints(prefix);
-	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV)
+	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV
+	    || size > MAX_ADDR_LEN)
 		print_quoted_string((const char *) addr, size,
 				    QUOTE_FORCE_HEX);
-	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW)
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW
+	    || size > MAX_ADDR_LEN)
 		return;
 	(xlat_verbose(xlat_verbosity) == XLAT_STYLE_VERBOSE
 		? tprints_comment : tprints)(sprint_hwaddr(addr, size,
