@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,7 +10,9 @@
 
 #include DEF_MPERS_TYPE(timeval_t)
 
-typedef struct timeval timeval_t;
+#include "kernel_timeval.h"
+
+typedef kernel_old_timeval_t timeval_t;
 
 #include MPERS_DEFS
 
