@@ -11,28 +11,9 @@
 
 #include "defs.h"
 
-#include DEF_MPERS_TYPE(rusage_t)
+#include DEF_MPERS_TYPE(kernel_rusage_t)
 
-#include "kernel_timeval.h"
-
-typedef struct {
-	kernel_old_timeval_t ru_utime;
-	kernel_old_timeval_t ru_stime;
-	kernel_long_t	ru_maxrss;
-	kernel_long_t	ru_ixrss;
-	kernel_long_t	ru_idrss;
-	kernel_long_t	ru_isrss;
-	kernel_long_t	ru_minflt;
-	kernel_long_t	ru_majflt;
-	kernel_long_t	ru_nswap;
-	kernel_long_t	ru_inblock;
-	kernel_long_t	ru_oublock;
-	kernel_long_t	ru_msgsnd;
-	kernel_long_t	ru_msgrcv;
-	kernel_long_t	ru_nsignals;
-	kernel_long_t	ru_nvcsw;
-	kernel_long_t	ru_nivcsw;
-} rusage_t;
+#include "kernel_rusage.h"
 
 #include MPERS_DEFS
 
@@ -42,7 +23,7 @@ typedef struct {
 MPERS_PRINTER_DECL(void, printrusage,
 		   struct tcb *const tcp, const kernel_ulong_t addr)
 {
-	rusage_t ru;
+	kernel_rusage_t ru;
 
 	if (umove_or_printaddr(tcp, addr, &ru))
 		return;
