@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,6 +8,6 @@
 #ifndef STRACE_PRINTSIGINFO_H
 # define STRACE_PRINTSIGINFO_H
 
-extern void printsiginfo(const siginfo_t *);
+extern void printsiginfo(struct tcb *, const siginfo_t *);
 
 #endif /* !STRACE_PRINTSIGINFO_H */
