@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2004 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2004-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -18,6 +18,12 @@ typedef struct rtc_pll_info struct_rtc_pll_info;
 
 #include MPERS_DEFS
 
+#include "xlat/rtc_vl_flags.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/rtc_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
 static void
 print_rtc_time(struct tcb *tcp, const struct rtc_time *rt)
 {
@@ -65,6 +71,19 @@ decode_rtc_pll_info(struct tcb *const tcp, const kernel_ulong_t addr)
 			pll.pll_posmult, pll.pll_negmult, (long) pll.pll_clock);
 }
 
+static void
+decode_rtc_vl(struct tcb *const tcp, const kernel_ulong_t addr)
+{
+	unsigned int val;
+
+	if (umove_or_printaddr(tcp, addr, &val))
+		return;
+
+	tprints("[");
+	printflags(rtc_vl_flags, val, "RTC_VL_???");
+	tprints("]");
+}
+
 MPERS_PRINTER_DECL(int, rtc_ioctl, struct tcb *const tcp,
 		   const unsigned int code, const kernel_ulong_t arg)
 {
@@ -106,14 +125,12 @@ MPERS_PRINTER_DECL(int, rtc_ioctl, struct tcb *const tcp,
 		tprints(", ");
 		decode_rtc_pll_info(tcp, arg);
 		break;
-#ifdef RTC_VL_READ
 	case RTC_VL_READ:
 		if (entering(tcp))
 			return 0;
 		tprints(", ");
-		printnum_int(tcp, arg, "%d");
+		decode_rtc_vl(tcp, arg);
 		break;
-#endif
 	case RTC_AIE_ON:
 	case RTC_AIE_OFF:
 	case RTC_UIE_ON:
@@ -122,9 +139,7 @@ MPERS_PRINTER_DECL(int, rtc_ioctl, struct tcb *const tcp,
 	case RTC_PIE_OFF:
 	case RTC_WIE_ON:
 	case RTC_WIE_OFF:
-#ifdef RTC_VL_CLR
 	case RTC_VL_CLR:
-#endif
 		/* no args */
 		break;
 	default:
