@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -29,6 +29,7 @@
 # define CST	0
 # define TSD	0
 # define TC	0
+# define TCL	0
 # define SEN(a)	0, 0
 
 #else	/*	!STRACE_TESTS_H	*/
@@ -55,6 +56,7 @@
 # define CST	COMPAT_SYSCALL_TYPES
 # define TSD	TRACE_SECCOMP_DEFAULT
 # define TC	TRACE_CREDS
+# define TCL	TRACE_CLOCK
 /* SEN(a) is defined elsewhere */
 
 #endif
