@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -19,9 +19,13 @@
 #undef TSF
 #undef TFSF
 #undef TSFA
+#undef PU
 #undef NF
 #undef MA
 #undef SI
 #undef SE
 #undef CST
+#undef TSD
+#undef TC
+#undef TCL
 #undef SEN
