@@ -1,7 +1,7 @@
 /*
  * IFLA_LINKINFO netlink attribute decoding check.
  *
- * Copyright (c) 2018 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,8 +24,8 @@
 #include <linux/rtnetlink.h>
 
 #define XLAT_MACROS_ONLY
-# include <xlat/rtnl_link_attrs.h>
-# include <xlat/rtnl_ifla_info_attrs.h>
+#include <xlat/rtnl_link_attrs.h>
+#include <xlat/rtnl_ifla_info_attrs.h>
 #undef XLAT_MACROS_ONLY
 
 #define IFLA_ATTR IFLA_LINKINFO
@@ -347,10 +347,9 @@ main(void)
 	/* bridge attrs */
 	static const struct val_name und_br_attrs[] = {
 		{ 0, "IFLA_BR_UNSPEC" },
-		{ 20, "IFLA_BR_GROUP_ADDR" },
 		{ 21, "IFLA_BR_FDB_FLUSH" },
 		{ 40, "IFLA_BR_PAD" },
-		{ 46, "0x2e /* IFLA_BR_??? */" },
+		{ 47, "0x2f /* IFLA_BR_??? */" },
 	};
 
 	for (size_t k = 0; k < ARRAY_SIZE(und_br_attrs); k++) {
@@ -367,6 +366,21 @@ main(void)
 					"\\x63\\x64\\x65\\x66\"" });
 	}
 
+	static const struct val_name hwa_br_attrs[] = {
+		{ 20, "IFLA_BR_GROUP_ADDR" },
+	};
+
+	for (size_t k = 0; k < ARRAY_SIZE(hwa_br_attrs); k++) {
+		TEST_NESTED_LINKINFO(fd, nlh0, 2, "IFLA_INFO_DATA", "bridge",
+				     hwa_br_attrs[k].val, hwa_br_attrs[k].name,
+				     unknown_msg, pattern,
+				     { 2, "ab:ac" },
+				     { 4, "ab:ac:db:cd" },
+				     { 6, "ab:ac:db:cd:61:62" },
+				     { 8, "ab:ac:db:cd:61:62:63:64" },
+				     { 10, "ab:ac:db:cd:61:62:63:64:65:66" });
+	}
+
 	static const struct val_name u64_br_attrs[] = {
 		{ 16, "IFLA_BR_HELLO_TIMER" },
 		{ 17, "IFLA_BR_TCN_TIMER" },
