@@ -1,5 +1,12 @@
+/*
+ * Copyright (c) 2016-2019 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
 #include "tests.h"
-#include <sys/syscall.h>
+#include "scno.h"
 
 #ifdef __NR_vhangup
 
@@ -21,10 +28,7 @@ main(void)
 	 * The system call, however, returns 0 iff the calling process
 	 * has CAP_SYS_TTY_CONFIG capability.
 	 */
-	if (rc)
-		printf("vhangup() = %ld %s (%m)\n", rc, errno2name());
-	else
-		puts("vhangup() = 0");
+	printf("vhangup() = %s\n", sprintrc(rc));
 
 	puts("+++ exited with 0 +++");
 	return 0;
