@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,7 +8,7 @@
 
 #include "tests.h"
 
-#include <asm/unistd.h>
+#include "scno.h"
 
 #ifdef __NR_futex
 
@@ -495,7 +495,7 @@ main(int argc, char *argv[])
 	 *                 wake val2 processes waiting for uaddr2 in case
 	 *                 operation encoded in val3 (change of value at uaddr2
 	 *                 and comparison of previous value against provided
-	 *                 constant) succeedes with value at uaddr2. Operation
+	 *                 constant) succeeds with value at uaddr2. Operation
 	 *                 result is written to value of uaddr2 (in any case).
 	 * 1. uaddr   - futex address
 	 * 2. op      - FUTEX_WAKE_OP
