@@ -1,7 +1,7 @@
 /*
  * Check decoding of io_uring_enter syscall.
  *
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -66,9 +66,9 @@ main(void)
 
 	sys_io_uring_enter(fd, to_submit, min_complete, -1U, sigmask, size);
 	printf("io_uring_enter(%u<%s>, %u, %u"
-	       ", IORING_ENTER_GETEVENTS|IORING_ENTER_SQ_WAKEUP|%#x"
-	       ", %s, %u) = %s\n",
-	       fd, path, to_submit, min_complete, -1U - 3,
+	       ", IORING_ENTER_GETEVENTS|IORING_ENTER_SQ_WAKEUP"
+	       "|IORING_ENTER_SQ_WAIT|%#x, %s, %u) = %s\n",
+	       fd, path, to_submit, min_complete, -1U - 7U,
 	       "~[HUP KILL STOP]", size, errstr);
 
 	puts("+++ exited with 0 +++");
