@@ -2,33 +2,15 @@
  * Check decoding of move_pages syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. The name of the author may not be used to endorse or promote products
- *    derived from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
+#include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_move_pages
 
@@ -62,7 +44,7 @@ print_page_array(const void **const pages,
 				break;
 			}
 		} else {
-			printf("%p", pages + i);
+			printf("... /* %p */", pages + i);
 			break;
 		}
 		const void *const addr = pages[i];
@@ -98,7 +80,7 @@ print_node_array(const int *const nodes,
 				break;
 			}
 		} else {
-			printf("%p", nodes + i);
+			printf("... /* %p */", nodes + i);
 			break;
 		}
 		printf("%d", nodes[i]);
@@ -125,23 +107,36 @@ print_status_array(const int *const status, const unsigned long count)
 		if (status[i] >= 0) {
 			printf("%d", status[i]);
 		} else {
+# if !XLAT_RAW
 			errno = -status[i];
-			printf("%s", errno2name());
+# endif
+# if XLAT_RAW
+			printf("%d", status[i]);
+# elif XLAT_VERBOSE
+			printf("%d /* -%s */", status[i], errno2name());
+# else
+			printf("-%s", errno2name());
+# endif
 		}
 	}
 	printf("]");
 }
 
 static void
-print_stat_pages(const unsigned long pid, const unsigned long count,
-		 const void **const pages, int *const status)
+print_stat_pages(const unsigned long pid,
+		 const char *pid_str,
+		 const unsigned long count,
+		 const void **const pages,
+		 int *const status)
 {
 	const unsigned long flags = (unsigned long) 0xfacefeed00000002ULL;
 
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, NULL, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, 0);
 	printf(", NULL, ");
 	if (rc) {
@@ -152,11 +147,18 @@ print_stat_pages(const unsigned long pid, const unsigned long count,
 	} else {
 		print_status_array(status, count);
 	}
+# if XLAT_RAW
+	printf(", 0x2) = %s\n", errstr);
+# elif XLAT_VERBOSE
+	printf(", 0x2 /* MPOL_MF_MOVE */) = %s\n", errstr);
+# else /* XLAT_ABBREV */
 	printf(", MPOL_MF_MOVE) = %s\n", errstr);
+# endif
 }
 
 static void
 print_move_pages(const unsigned long pid,
+		 const char *pid_str,
 		 unsigned long count,
 		 const unsigned int offset,
 		 const void **const pages,
@@ -169,7 +171,9 @@ print_move_pages(const unsigned long pid,
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, nodes, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, offset);
 	printf(", ");
 	print_node_array(nodes, count, offset);
@@ -178,56 +182,66 @@ print_move_pages(const unsigned long pid,
 		printf("%p", status);
 	else
 		printf("[]");
+# if XLAT_RAW
+	printf(", 0x4) = %s\n", errstr);
+# elif XLAT_VERBOSE
+	printf(", 0x4 /* MPOL_MF_MOVE_ALL */) = %s\n", errstr);
+# else /* XLAT_ABBREV */
 	printf(", MPOL_MF_MOVE_ALL) = %s\n", errstr);
+# endif
 }
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const unsigned long pid =
 		(unsigned long) 0xfacefeed00000000ULL | getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	unsigned long count = 1;
 	const unsigned page_size = get_page_size();
 	const void *const page = tail_alloc(page_size);
 	const void *const efault = page + page_size;
-	const void **pages = tail_alloc(sizeof(*pages));
-	int *nodes = tail_alloc(sizeof(*nodes));
-	int *status = tail_alloc(sizeof(*status));
+	TAIL_ALLOC_OBJECT_VAR_PTR(const void *, pages);
+	TAIL_ALLOC_OBJECT_VAR_PTR(int, nodes);
+	TAIL_ALLOC_OBJECT_VAR_PTR(int, status);
 
-	print_stat_pages(pid, 0, pages, status);
-	print_move_pages(pid, 0, 0, pages, nodes, status);
-	print_move_pages(pid, 0, 1, pages + 1, nodes + 1, status + 1);
+	print_stat_pages(pid, pid_str, 0, pages, status);
+	print_move_pages(pid, pid_str, 0, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, 0, 1, pages + 1, nodes + 1, status + 1);
 
 	*pages = page;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*nodes = 0xdeadbee1;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = efault;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee2;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = nodes;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee3;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = status;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee4;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
