@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,8 @@
 #endif
 #define IFLA_LINK_NETNSID 37
 #define IFLA_EVENT 44
+#define IFLA_PROP_LIST 52
+#define IFLA_ALT_IFNAME 53
 
 #ifndef IFLA_INFO_KIND
 # define IFLA_INFO_KIND 1
@@ -36,6 +38,8 @@
 # define IFLA_VF_PORT 1
 #endif
 
+static const unsigned int hdrlen = sizeof(struct ifinfomsg);
+
 static void
 init_ifinfomsg(struct nlmsghdr *const nlh, const unsigned int msg_len)
 {
@@ -65,6 +69,27 @@ print_ifinfomsg(const unsigned int msg_len)
 	       msg_len);
 }
 
+static void
+init_prop_list_msg(struct nlmsghdr *const nlh,
+		     const unsigned int msg_len)
+{
+	init_ifinfomsg(nlh, msg_len);
+
+	struct nlattr *nla = NLMSG_ATTR(nlh, hdrlen);
+	SET_STRUCT(struct nlattr, nla,
+		.nla_len = msg_len - NLMSG_SPACE(hdrlen),
+		.nla_type = IFLA_PROP_LIST,
+	);
+}
+
+static void
+print_prop_list_msg(const unsigned int msg_len)
+{
+	print_ifinfomsg(msg_len);
+	printf(", {{nla_len=%u, nla_type=IFLA_PROP_LIST}",
+	       msg_len - NLMSG_SPACE(hdrlen));
+}
+
 int
 main(void)
 {
@@ -96,9 +121,8 @@ main(void)
 		.tx_compressed = 0xefdadfab
 	};
 	const int fd = create_nl_socket(NETLINK_ROUTE);
-	const unsigned int hdrlen = sizeof(struct ifinfomsg);
 	void *nlh0 = midtail_alloc(NLMSG_SPACE(hdrlen),
-				   NLA_HDRLEN + sizeof(st));
+				   2 * NLA_HDRLEN + MAX(sizeof(st), 20));
 
 	static char pattern[4096];
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
@@ -118,40 +142,39 @@ main(void)
 			   IFLA_LINK_NETNSID, pattern, netnsid,
 			   printf("%d", netnsid));
 
-	TEST_NLATTR_OBJECT(fd, nlh0, hdrlen,
-			   init_ifinfomsg, print_ifinfomsg,
-			   IFLA_STATS, pattern, st,
-			   PRINT_FIELD_U("{", st, rx_packets);
-			   PRINT_FIELD_U(", ", st, tx_packets);
-			   PRINT_FIELD_U(", ", st, rx_bytes);
-			   PRINT_FIELD_U(", ", st, tx_bytes);
-			   PRINT_FIELD_U(", ", st, rx_errors);
-			   PRINT_FIELD_U(", ", st, tx_errors);
-			   PRINT_FIELD_U(", ", st, rx_dropped);
-			   PRINT_FIELD_U(", ", st, tx_dropped);
-			   PRINT_FIELD_U(", ", st, multicast);
-			   PRINT_FIELD_U(", ", st, collisions);
-			   PRINT_FIELD_U(", ", st, rx_length_errors);
-			   PRINT_FIELD_U(", ", st, rx_over_errors);
-			   PRINT_FIELD_U(", ", st, rx_crc_errors);
-			   PRINT_FIELD_U(", ", st, rx_frame_errors);
-			   PRINT_FIELD_U(", ", st, rx_fifo_errors);
-			   PRINT_FIELD_U(", ", st, rx_missed_errors);
-			   PRINT_FIELD_U(", ", st, tx_aborted_errors);
-			   PRINT_FIELD_U(", ", st, tx_carrier_errors);
-			   PRINT_FIELD_U(", ", st, tx_fifo_errors);
-			   PRINT_FIELD_U(", ", st, tx_heartbeat_errors);
-			   PRINT_FIELD_U(", ", st, tx_window_errors);
-			   PRINT_FIELD_U(", ", st, rx_compressed);
-			   PRINT_FIELD_U(", ", st, tx_compressed);
+	const unsigned int sizeof_stats =
+		offsetofend(struct rtnl_link_stats, tx_compressed);
+	TEST_NLATTR_OBJECT_MINSZ(fd, nlh0, hdrlen,
+				 init_ifinfomsg, print_ifinfomsg,
+				 IFLA_STATS, pattern, st, sizeof_stats,
+				 PRINT_FIELD_U("{", st, rx_packets);
+				 PRINT_FIELD_U(", ", st, tx_packets);
+				 PRINT_FIELD_U(", ", st, rx_bytes);
+				 PRINT_FIELD_U(", ", st, tx_bytes);
+				 PRINT_FIELD_U(", ", st, rx_errors);
+				 PRINT_FIELD_U(", ", st, tx_errors);
+				 PRINT_FIELD_U(", ", st, rx_dropped);
+				 PRINT_FIELD_U(", ", st, tx_dropped);
+				 PRINT_FIELD_U(", ", st, multicast);
+				 PRINT_FIELD_U(", ", st, collisions);
+				 PRINT_FIELD_U(", ", st, rx_length_errors);
+				 PRINT_FIELD_U(", ", st, rx_over_errors);
+				 PRINT_FIELD_U(", ", st, rx_crc_errors);
+				 PRINT_FIELD_U(", ", st, rx_frame_errors);
+				 PRINT_FIELD_U(", ", st, rx_fifo_errors);
+				 PRINT_FIELD_U(", ", st, rx_missed_errors);
+				 PRINT_FIELD_U(", ", st, tx_aborted_errors);
+				 PRINT_FIELD_U(", ", st, tx_carrier_errors);
+				 PRINT_FIELD_U(", ", st, tx_fifo_errors);
+				 PRINT_FIELD_U(", ", st, tx_heartbeat_errors);
+				 PRINT_FIELD_U(", ", st, tx_window_errors);
+				 PRINT_FIELD_U(", ", st, rx_compressed);
+				 PRINT_FIELD_U(", ", st, tx_compressed);
 #ifdef HAVE_STRUCT_RTNL_LINK_STATS_RX_NOHANDLER
-			   PRINT_FIELD_U(", ", st, rx_nohandler);
+				 PRINT_FIELD_U(", ", st, rx_nohandler);
 #endif
 			   printf("}"));
 
-#ifdef HAVE_STRUCT_RTNL_LINK_STATS_RX_NOHANDLER
-	const unsigned int sizeof_stats =
-		offsetofend(struct rtnl_link_stats, tx_compressed);
 	TEST_NLATTR(fd, nlh0, hdrlen,
 		    init_ifinfomsg, print_ifinfomsg,
 		    IFLA_STATS, sizeof_stats, &st, sizeof_stats,
@@ -179,7 +202,6 @@ main(void)
 		    PRINT_FIELD_U(", ", st, rx_compressed);
 		    PRINT_FIELD_U(", ", st, tx_compressed);
 		    printf("}"));
-#endif /* HAVE_STRUCT_RTNL_LINK_STATS_RX_NOHANDLER */
 
 	static const struct rtnl_link_ifmap map = {
 		.mem_start = 0xadcbefedefbcdedb,
@@ -341,6 +363,33 @@ main(void)
 				   printf("%s", ifla_events[i].str));
 	}
 
+	/* IFLA_PROP_LIST */
+	struct {
+		char p1[20];
+	} buf;
+	fill_memory(&buf, sizeof(buf));
+	TEST_NESTED_NLATTR_OBJECT_EX_(fd, nlh0, hdrlen,
+				      init_prop_list_msg, print_prop_list_msg,
+				      IFLA_ALT_IFNAME, "IFLA_ALT_IFNAME",
+				      pattern, buf, print_quoted_stringn, 1,
+				      print_quoted_memory(&buf, sizeof(buf));
+				      printf("..."));
+
+	/* IFLA_ALT_IFNAME */
+	static const char alt_ifname[] = "OH HAI THAR\r\n\t\377\0\v\x7e";
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname), alt_ifname, sizeof(alt_ifname),
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1));
+
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname) - 1, alt_ifname, sizeof(alt_ifname) - 1,
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1);
+		    printf("..."));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
