@@ -1,13 +1,13 @@
 /*
  * Copyright (c) 2016 Katerina Koukiou <k.koukiou@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
+#include "scno.h"
 
 #ifdef __NR_openat
 
@@ -15,12 +15,12 @@
 # include <stdio.h>
 # include <unistd.h>
 
-#ifdef O_TMPFILE
+# ifdef O_TMPFILE
 /* The kernel & C libraries often inline O_DIRECTORY. */
-# define STRACE_O_TMPFILE (O_TMPFILE & ~O_DIRECTORY)
-#else
-# define STRACE_O_TMPFILE 0
-#endif
+#  define STRACE_O_TMPFILE (O_TMPFILE & ~O_DIRECTORY)
+# else
+#  define STRACE_O_TMPFILE 0
+# endif
 
 static const char sample[] = "openat.sample";
 
