@@ -2,14 +2,14 @@
  * Check verbose decoding of perf_event_open syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
+#include "scno.h"
 
 #if defined(__NR_perf_event_open) && defined(HAVE_LINUX_PERF_EVENT_H)
 
@@ -137,7 +137,7 @@ print_event_attr(struct perf_event_attr *attr_ptr, size_t size,
 		STRACE_PEA_ABBREV_SIZE =
 			offsetof(struct perf_event_attr, config) +
 			sizeof(attr_ptr->config),
-		STRACE_PEA_SIZE = 112,
+		STRACE_PEA_SIZE = 120,
 	};
 
 	uint32_t read_size;
@@ -476,6 +476,28 @@ print_event_attr(struct perf_event_attr *attr_ptr, size_t size,
 		goto end;
 	}
 
+	val = ((uint16_t *) attr)[110 / sizeof(uint16_t)];
+	if (val)
+		printf(" /* bytes 110..111: %#" PRIx16 " */", (uint16_t) val);
+
+	if (size <= 112) {
+		cutoff = 112;
+		goto end;
+	}
+
+	val =
+#  ifdef HAVE_STRUCT_PERF_EVENT_ATTR_AUX_SAMPLE_SIZE
+		attr->aux_sample_size;
+#  else
+		((uint32_t *) attr)[112 / sizeof(uint32_t)];
+#  endif
+	printf(", aux_sample_size=%" PRIu32, (uint32_t) val);
+
+	if (size <= 116) {
+		cutoff = 116;
+		goto end;
+	}
+
 	cutoff = STRACE_PEA_SIZE;
 
 end:
@@ -489,7 +511,7 @@ end:
 }
 
 /* These require aligned access, so no byte-grain checks possible */
-# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64
+# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64 || defined ARM
 #  define ATTR_REC(sz) { tail_alloc((sz + 7) & ~7), sz }
 # else
 #  define ATTR_REC(sz) { tail_alloc(sz), sz }
@@ -512,7 +534,8 @@ end:
 	"PERF_SAMPLE_BRANCH_CALL|" \
 	"PERF_SAMPLE_BRANCH_NO_FLAGS|" \
 	"PERF_SAMPLE_BRANCH_NO_CYCLES|" \
-	"PERF_SAMPLE_BRANCH_TYPE_SAVE"
+	"PERF_SAMPLE_BRANCH_TYPE_SAVE|" \
+	"PERF_SAMPLE_BRANCH_HW_INDEX"
 
 int
 main(void)
@@ -529,7 +552,11 @@ main(void)
 	static const size_t attr_v4_625_size = PERF_ATTR_SIZE_VER4 + 5;
 	static const size_t attr_v4_875_size = PERF_ATTR_SIZE_VER4 + 7;
 	static const size_t attr_v5_size = PERF_ATTR_SIZE_VER5;
-	static const size_t attr_big_size = PERF_ATTR_SIZE_VER5 + 32;
+	static const size_t attr_v5_25_size = PERF_ATTR_SIZE_VER5 + 2;
+	static const size_t attr_v5_5_size = PERF_ATTR_SIZE_VER5 + 4;
+	static const size_t attr_v5_75_size = PERF_ATTR_SIZE_VER5 + 6;
+	static const size_t attr_v6_size = PERF_ATTR_SIZE_VER6;
+	static const size_t attr_big_size = PERF_ATTR_SIZE_VER6 + 32;
 
 	static const struct u64_val_str attr_types[] = {
 		{ ARG_STR(PERF_TYPE_HARDWARE) },
@@ -597,7 +624,7 @@ main(void)
 	static const struct u64_val_str sample_types[] = {
 		{ ARG_STR(0) },
 		{ 0x800, "PERF_SAMPLE_BRANCH_STACK" },
-		{ ARG_ULL_STR(0xdeadc0deda700000) " /* PERF_SAMPLE_??? */" },
+		{ ARG_ULL_STR(0xdeadc0deda600000) " /* PERF_SAMPLE_??? */" },
 		{ 0xffffffffffffffffULL,
 			"PERF_SAMPLE_IP|PERF_SAMPLE_TID|PERF_SAMPLE_TIME|"
 			"PERF_SAMPLE_ADDR|PERF_SAMPLE_READ|"
@@ -608,7 +635,8 @@ main(void)
 			"PERF_SAMPLE_WEIGHT|PERF_SAMPLE_DATA_SRC|"
 			"PERF_SAMPLE_IDENTIFIER|PERF_SAMPLE_TRANSACTION|"
 			"PERF_SAMPLE_REGS_INTR|PERF_SAMPLE_PHYS_ADDR|"
-			"0xfffffffffff00000" },
+			"PERF_SAMPLE_AUX|"
+			"0xffffffffffe00000" },
 	};
 	static const struct u64_val_str read_formats[] = {
 		{ ARG_STR(0) },
@@ -640,11 +668,11 @@ main(void)
 	static const struct u64_val_str branch_sample_types[] = {
 		{ ARG_STR(0) },
 		{ 0x80, "PERF_SAMPLE_BRANCH_ABORT_TX" },
-		{ 0x1ffff, BRANCH_TYPE_ALL },
+		{ 0x3ffff, BRANCH_TYPE_ALL },
 		{ ARG_ULL_STR(0xdeadcaffeeec0000)
 			" /* PERF_SAMPLE_BRANCH_??? */" },
 		{ 0xffffffffffffffffULL,
-			BRANCH_TYPE_ALL "|0xfffffffffffe0000" }
+			BRANCH_TYPE_ALL "|0xfffffffffffc0000" }
 	};
 	static const struct s32_val_str clockids[] = {
 		{ 11, "CLOCK_TAI" },
@@ -669,6 +697,10 @@ main(void)
 		ATTR_REC(attr_v4_625_size),
 		ATTR_REC(attr_v4_875_size),
 		ATTR_REC(attr_v5_size),
+		ATTR_REC(attr_v5_25_size),
+		ATTR_REC(attr_v5_5_size),
+		ATTR_REC(attr_v5_75_size),
+		ATTR_REC(attr_v6_size),
 		ATTR_REC(attr_big_size),
 	};
 
@@ -776,6 +808,10 @@ main(void)
 		ip_desc_str = precise_ip_descs[flags_data.flags.precise_ip];
 # endif
 
+		if (((i % 17) == 3) && (size >= 112))
+			((uint16_t *) attr)[110 / sizeof(uint16_t)] = 0;
+
+
 		if (i == 0)
 			attr->size = size + 8;
 
