@@ -2,14 +2,14 @@
  * Check decoding of ptrace syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
+#include "scno.h"
 
 #include <errno.h>
 #include "ptrace.h"
@@ -127,16 +127,16 @@ test_peeksiginfo(unsigned long pid, const unsigned long bad_request)
 			printf("ptrace(PTRACE_PEEKSIGINFO, %u"
 			       ", {off=%llu, flags=0, nr=%u}"
 			       ", [{si_signo=SIGUSR1, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGUSR2, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGALRM, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       "]) = %s\n",
 			       (unsigned) pid, psi->off, psi->nr,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
 			       errstr);
 		}
 
@@ -307,7 +307,7 @@ main(void)
 
 	do_ptrace(PTRACE_SETSIGINFO, pid, bad_request, (unsigned long) sip);
 	printf("ptrace(PTRACE_SETSIGINFO, %u, %#lx, {si_signo=SIGBUS"
-	       ", si_code=BUS_ADRALN, si_errno=%d, si_addr=%p}) = %s\n",
+	       ", si_code=BUS_ADRALN, si_errno=%u, si_addr=%p}) = %s\n",
 	       (unsigned) pid, bad_request, sip->si_errno, sip->si_addr,
 	       errstr);
 
@@ -321,7 +321,7 @@ main(void)
 
 	do_ptrace(PTRACE_SETSIGINFO, pid, bad_request, (unsigned long) sip);
 	printf("ptrace(PTRACE_SETSIGINFO, %u, %#lx, {si_signo=SIGPROF"
-	       ", si_code=%#x, si_errno=%d, si_pid=0, si_uid=3}) = %s\n",
+	       ", si_code=%#x, si_errno=%u, si_pid=0, si_uid=3}) = %s\n",
 	       (unsigned) pid, bad_request, sip->si_code, sip->si_errno,
 	       errstr);
 
@@ -349,7 +349,7 @@ main(void)
 
 	do_ptrace(PTRACE_SETSIGINFO, pid, bad_request, (unsigned long) sip);
 	printf("ptrace(PTRACE_SETSIGINFO, %u, %#lx, {si_signo=SIGSYS"
-	       ", si_code=SYS_SECCOMP, si_errno=%d, si_call_addr=NULL"
+	       ", si_code=SYS_SECCOMP, si_errno=%u, si_call_addr=NULL"
 	       ", si_syscall=__NR_read, si_arch=%#x /* AUDIT_ARCH_??? */})"
 	       " = %s\n",
 	       (unsigned) pid, bad_request, sip->si_errno, sip->si_arch,
