@@ -2,14 +2,14 @@
  * Check success injection.
  *
  * Copyright (c) 2017 Elvira Khabirova <lineprinter0@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
+#include "scno.h"
 
 #ifdef __NR_chdir
 
