@@ -2,7 +2,7 @@
  * Check decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,7 +11,7 @@
 #include "tests.h"
 
 #include <stdio.h>
-#include <asm/unistd.h>
+#include "scno.h"
 #include <unistd.h>
 
 #ifdef HAVE_LINUX_SECCOMP_H
@@ -37,12 +37,14 @@ main(void)
 	printf("seccomp(SECCOMP_SET_MODE_FILTER, %s, {len=%u, filter=%p})"
 	       " = %ld %s (%m)\n",
 	       "SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
-	       "SECCOMP_FILTER_FLAG_SPEC_ALLOW|0xfffffff8",
+	       "SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
+	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+	       "SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 	       prog->len, prog->filter, rc, errno2name());
 
-	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -8L, efault);
+	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -32L, efault);
 	printf("seccomp(SECCOMP_SET_MODE_FILTER, %s, %p) = %ld %s (%m)\n",
-	       "0xfffffff8 /* SECCOMP_FILTER_FLAG_??? */",
+	       "0xffffffe0 /* SECCOMP_FILTER_FLAG_??? */",
 	       efault, rc, errno2name());
 
 	puts("+++ exited with 0 +++");
