@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -46,6 +46,7 @@ typedef off_t libc_off_t;
 # define stat64 libc_stat64
 # define statx libc_statx
 # define statx_timestamp libc_statx_timestamp
+struct statx;
 # include <fcntl.h>
 # include <sys/stat.h>
 # undef statx_timestamp
@@ -101,7 +102,7 @@ typedef off_t libc_off_t;
 #  define IS_STATX 0
 # endif
 
-#if !XLAT_RAW /* Fixes -Wunused warning */
+# if !XLAT_RAW /* Fixes -Wunused warning */
 static void
 print_ftype(const unsigned int mode)
 {
@@ -122,24 +123,24 @@ print_perms(const unsigned int mode)
 {
 	printf("%#o", mode & ~S_IFMT);
 }
-#endif
+# endif
 
 static void
 print_st_mode(const unsigned int mode)
 {
-#if XLAT_RAW
+# if XLAT_RAW
 	printf("%#o", mode);
-#elif XLAT_VERBOSE
+# elif XLAT_VERBOSE
 	printf("%#o /* ", mode);
 	print_ftype(mode);
 	printf("|");
 	print_perms(mode);
 	printf(" */");
-#else
+# else
 	print_ftype(mode);
 	printf("|");
 	print_perms(mode);
-#endif
+# endif
 }
 
 # if !IS_STATX
@@ -150,18 +151,18 @@ sprint_makedev(const unsigned long long val)
 	static char devid[256];
 	int ret;
 
-#if XLAT_RAW
+#  if XLAT_RAW
 	ret = snprintf(devid, sizeof(devid),
 			"%#llx", val);
-#elif XLAT_VERBOSE
+#  elif XLAT_VERBOSE
 	ret = snprintf(devid, sizeof(devid),
 			"%#llx /* makedev(%#x, %#x) */",
 			val, major(val), minor(val));
-#else /* XLAT_ABBREV */
+#  else /* XLAT_ABBREV */
 	ret = snprintf(devid, sizeof(devid),
 			"makedev(%#x, %#x)",
 			major(val), minor(val));
-#endif
+#  endif
 	if (ret < 0)
 		perror_msg_and_fail("sprint_makedev(%llx)", val);
 	if ((unsigned) ret >= sizeof(devid))
@@ -208,7 +209,7 @@ print_stat(const STRUCT_STAT *st)
 #   define HAVE_NSEC		0
 #  endif
 
-#define PRINT_ST_TIME(field)							\
+#  define PRINT_ST_TIME(field)							\
 	do {									\
 		printf(", st_" #field "=%lld",					\
 		       sign_extend_unsigned_to_ll(st->st_ ## field));		\
@@ -460,19 +461,19 @@ main(void)
 	SET_FLAGS_INVOKE(0xffffff,
 		"AT_STATX_FORCE_SYNC|AT_STATX_DONT_SYNC|AT_SYMLINK_NOFOLLOW|"
 		"AT_REMOVEDIR|AT_SYMLINK_FOLLOW|AT_NO_AUTOMOUNT|AT_EMPTY_PATH|"
-		"0xff80ff");
+		"AT_RECURSIVE|0xff00ff");
 
 	/* We're done playing with flags. */
 	TEST_SYSCALL_STATX_FLAGS = old_flags;
 	TEST_SYSCALL_STATX_FLAGS_STR = old_flags_str;
 
 	SET_MASK_INVOKE(0, "0");
-	SET_MASK_INVOKE(0xfffff000U, "0xfffff000 /* STATX_??? */");
+	SET_MASK_INVOKE(0xffffe000U, "0xffffe000 /* STATX_??? */");
 
 	SET_MASK_INVOKE(0xfffffffbU,
 		"STATX_TYPE|STATX_MODE|STATX_UID|STATX_GID|STATX_ATIME|"
 		"STATX_MTIME|STATX_CTIME|STATX_INO|STATX_SIZE|STATX_BLOCKS|"
-		"STATX_BTIME|0xfffff000");
+		"STATX_BTIME|STATX_MNT_ID|0xffffe000");
 
 	SET_MASK_INVOKE(STATX_UID, "STATX_UID");
 
