@@ -2,7 +2,7 @@
  * Check decoding of getgroups/getgroups32 syscalls.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,7 +17,7 @@
 #else
 
 # include "tests.h"
-# include <asm/unistd.h>
+# include "scno.h"
 
 # ifdef __NR_getgroups
 
@@ -38,7 +38,7 @@
 # include <stdio.h>
 # include <unistd.h>
 
-#define MAX_STRLEN 32
+# define MAX_STRLEN 32
 static long ngroups;
 
 static void
