@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2014-2019 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
+#include "scno.h"
 
 #ifdef __NR_statfs
 
