@@ -160,10 +160,18 @@ int lock_file_by_dirname(const char *path_name, const char *lock_name);
  * and followed also by an unmapped page.
  */
 void *tail_alloc(const size_t)
-	ATTRIBUTE_MALLOC ATTRIBUTE_ALLOC_SIZE((1));
+	ATTRIBUTE_MALLOC
+# ifndef HAVE_BROKEN_CC
+	ATTRIBUTE_ALLOC_SIZE((1))
+# endif
+	;
 /* Allocate memory using tail_alloc, then memcpy. */
 void *tail_memdup(const void *, const size_t)
-	ATTRIBUTE_MALLOC ATTRIBUTE_ALLOC_SIZE((2));
+	ATTRIBUTE_MALLOC
+# ifndef HAVE_BROKEN_CC
+	ATTRIBUTE_ALLOC_SIZE((2))
+# endif
+	;
 
 # define midtail_alloc(after_, before_) \
 	((void *) ((char *) tail_alloc(((before_) + (after_))) + (before_)))
@@ -334,6 +342,9 @@ int send_mmsg(int, struct mmsghdr *, unsigned int, unsigned int);
 int create_nl_socket_ext(int proto, const char *name);
 # define create_nl_socket(proto)	create_nl_socket_ext((proto), #proto)
 
+/* Create a temporary file in the current directory. */
+int create_tmpfile(unsigned int flags);
+
 /* Create a pipe with maximized descriptor numbers. */
 void pipe_maxfd(int pipefd[2]);
 
