@@ -2,21 +2,33 @@
  * Check decoding of threads when a non-leader thread invokes execve.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <asm/unistd.h>
-#include <errno.h>
-#include <pthread.h>
-#include <signal.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <time.h>
-#include <unistd.h>
+#include "scno.h"
+
+#ifdef __NR_nanosleep
+
+# include <errno.h>
+# include <pthread.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <time.h>
+# include <unistd.h>
+
+# include "kernel_old_timespec.h"
+
+# ifndef PRINT_EXITED
+#  define PRINT_EXITED 1
+# endif
+# ifndef PRINT_SUPERSEDED
+#  define PRINT_SUPERSEDED 1
+# endif
 
 static pid_t leader;
 static pid_t tid;
@@ -110,9 +122,9 @@ thread(void *arg)
 	struct timespec ts = { .tv_nsec = 100000000 };
 	(void) clock_nanosleep(CLOCK_REALTIME, 0, &ts, NULL);
 
-	ts.tv_nsec = 12345;
+	kernel_old_timespec_t ots = { .tv_nsec = 12345 };
 	printf("%-5d nanosleep({tv_sec=0, tv_nsec=%u}, NULL) = 0\n",
-	       tid, (unsigned int) ts.tv_nsec);
+	       tid, (unsigned int) ots.tv_nsec);
 
 	switch (action % NUMBER_OF_ACTIONS) {
 		case ACTION_exit:
@@ -140,12 +152,12 @@ thread(void *arg)
 			break;
 	}
 
-	printf("%-5d +++ superseded by execve in pid %u +++\n"
-	       "%-5d <... execve resumed> ) = 0\n",
-	       leader, tid,
-	       leader);
+# if PRINT_SUPERSEDED
+	printf("%-5d +++ superseded by execve in pid %u +++\n", leader, tid);
+# endif
+	printf("%-5d <... execve resumed>) = 0\n", leader);
 
-	(void) nanosleep(&ts, NULL);
+	(void) syscall(__NR_nanosleep, (unsigned long) &ots, 0UL);
 	execve(argv[0], argv, environ);
 	perror_msg_and_fail("execve");
 }
@@ -178,7 +190,9 @@ main(int ac, char **av)
 	action = atoi(av[2]);
 
 	if (action >= NUMBER_OF_ACTIONS * NUMBER_OF_ITERATIONS) {
+# if PRINT_EXITED
 		printf("%-5d +++ exited with 0 +++\n", leader);
+# endif
 		return 0;
 	}
 
@@ -190,7 +204,7 @@ main(int ac, char **av)
 	if (errno)
 		perror_msg_and_fail("pthread_create");
 
-	struct timespec ts = { .tv_sec = 123 };
+	kernel_old_timespec_t ots = { .tv_sec = 123 };
 	sigset_t mask;
 	sigemptyset(&mask);
 
@@ -214,11 +228,18 @@ main(int ac, char **av)
 		case ACTION_nanosleep:
 			printf("%s nanosleep({tv_sec=%u, tv_nsec=0}"
 			       ",  <unfinished ...>\n",
-			       leader_str, (unsigned int) ts.tv_sec);
+			       leader_str, (unsigned int) ots.tv_sec);
 			close(fds[1]);
-			(void) nanosleep(&ts, 0);
+			(void) syscall(__NR_nanosleep,
+				       (unsigned long) &ots, 0UL);
 			break;
 	}
 
 	return 1;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_nanosleep")
+
+#endif
