@@ -28,7 +28,8 @@
 	CHECK_V4L2_STRUCT_SIZE(s_); \
 	CHECK_V4L2_RESERVED_SIZE(s_)
 
-#include DEF_MPERS_TYPE(struct_v4l2_buffer)
+#include DEF_MPERS_TYPE(kernel_v4l2_buffer_t)
+#include DEF_MPERS_TYPE(kernel_v4l2_event_t)
 #include DEF_MPERS_TYPE(struct_v4l2_clip)
 #include DEF_MPERS_TYPE(struct_v4l2_create_buffers)
 #include DEF_MPERS_TYPE(struct_v4l2_ext_control)
@@ -38,7 +39,7 @@
 #include DEF_MPERS_TYPE(struct_v4l2_input)
 #include DEF_MPERS_TYPE(struct_v4l2_standard)
 
-#include "types/v4l2.h"
+#include "kernel_v4l2_types.h"
 
 CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_capability);
 CHECK_V4L2_STRUCT_SIZE_LE(v4l2_pix_format);
@@ -171,7 +172,7 @@ print_v4l2_capability(struct tcb *const tcp, const kernel_ulong_t arg)
 	PRINT_FIELD_CSTRING("{", caps, driver);
 	PRINT_FIELD_CSTRING(", ", caps, card);
 	PRINT_FIELD_CSTRING(", ", caps, bus_info);
-	tprintf(", version=");
+	tprints(", version=");
 	print_kernel_version(caps.version);
 	tprints(", capabilities=");
 	printflags(v4l2_device_capabilities_flags, caps.capabilities,
@@ -398,7 +399,7 @@ print_v4l2_requestbuffers(struct tcb *const tcp, const kernel_ulong_t arg)
 		if (umove_or_printaddr(tcp, arg, &reqbufs))
 			return RVAL_IOCTL_DECODED;
 
-		tprintf("{type=");
+		tprints("{type=");
 		printxval(v4l2_buf_types, reqbufs.type, "V4L2_BUF_TYPE_???");
 		tprints(", memory=");
 		printxval(v4l2_memories, reqbufs.memory, "V4L2_MEMORY_???");
@@ -456,7 +457,7 @@ static int
 print_v4l2_buffer(struct tcb *const tcp, const unsigned int code,
 		  const kernel_ulong_t arg)
 {
-	struct_v4l2_buffer b;
+	kernel_v4l2_buffer_t b;
 
 	if (entering(tcp)) {
 		tprints(", ");
@@ -488,7 +489,15 @@ print_v4l2_buffer(struct tcb *const tcp, const unsigned int code,
 		print_v4l2_buffer_flags(b.flags);
 		if (code == VIDIOC_DQBUF) {
 			tprints(", timestamp=");
-			MPERS_FUNC_NAME(print_struct_timeval)(&b.timestamp);
+			kernel_timeval64_t t;
+			if (sizeof(t.tv_usec) == sizeof(b.timestamp.tv_usec)) {
+				print_timeval64_data_size(&b.timestamp,
+							  sizeof(b.timestamp));
+			} else {
+				t.tv_sec = b.timestamp.tv_sec;
+				t.tv_usec = zero_extend_signed_to_ull(b.timestamp.tv_usec);
+				print_timeval64_data_size(&t, sizeof(t));
+			}
 		}
 		tprints(", ...");
 	}
@@ -582,7 +591,7 @@ print_v4l2_streamparm(struct tcb *const tcp, const kernel_ulong_t arg,
 		printflags(v4l2_streaming_capabilities,
 			   s.parm.output.capability, "V4L2_CAP_???");
 
-		tprintf(", outputmode=");
+		tprints(", outputmode=");
 		printflags(v4l2_capture_modes,
 			   s.parm.output.outputmode, "V4L2_MODE_???");
 
